@@ -8,9 +8,9 @@ import (
 
 	"github.com/charmbracelet/huh"
 	"github.com/charmbracelet/lipgloss"
-	"github.com/mattn/go-isatty"
+	"github.com/charmbracelet/x/ansi"
+	"github.com/charmbracelet/x/term"
 
-	"github.com/charmbracelet/gum/ansi"
 	"github.com/charmbracelet/gum/internal/stdin"
 )
 
@@ -35,7 +35,7 @@ func (o Options) Run() error {
 	theme := huh.ThemeCharm()
 	options := huh.NewOptions(o.Options...)
 
-	theme.Focused.Base.Border(lipgloss.Border{})
+	theme.Focused.Base = lipgloss.NewStyle()
 	theme.Focused.Title = o.HeaderStyle.ToLipgloss()
 	theme.Focused.SelectSelector = o.CursorStyle.ToLipgloss().SetString(o.Cursor)
 	theme.Focused.MultiSelectSelector = o.CursorStyle.ToLipgloss().SetString(o.Cursor)
@@ -77,7 +77,6 @@ func (o Options) Run() error {
 			WithShowHelp(o.ShowHelp).
 			WithTheme(theme).
 			Run()
-
 		if err != nil {
 			return err
 		}
@@ -103,12 +102,11 @@ func (o Options) Run() error {
 		WithTheme(theme).
 		WithShowHelp(o.ShowHelp).
 		Run()
-
 	if err != nil {
 		return err
 	}
 
-	if isatty.IsTerminal(os.Stdout.Fd()) {
+	if term.IsTerminal(os.Stdout.Fd()) {
 		fmt.Println(choice)
 	} else {
 		fmt.Print(ansi.Strip(choice))
@@ -129,7 +127,7 @@ func widest(options []string) int {
 }
 
 func ansiprint(s string) {
-	if isatty.IsTerminal(os.Stdout.Fd()) {
+	if term.IsTerminal(os.Stdout.Fd()) {
 		fmt.Println(s)
 	} else {
 		fmt.Print(ansi.Strip(s))
